wipe;
model BasicBuilder -ndm 2 -ndf 2;

set tcl_precision 16;

# --- DEFINE MATERIAL MODELS
set ConcMat 1;
set ConcDiagMat 2;

# ConcretewBeta
set fpc  	[expr -4.0];
set ec0 	[expr -0.002];
set Ec		[expr 3600.]
set fcint 	[expr -2.];
set ecint 	[expr -0.004];
set fcres 	[expr -0.1];	
set ecres 	[expr -0.01];
set alpha	[expr 0.5]

set ft 		[expr 0.3];
set ftint 	[expr 0.01];
set etint 	[expr 0.001];
set ftres 	[expr 0.0];
set etres 	[expr 1.0];

set bint 	[expr 0.3];
set ebint 	[expr 0.01];
set bres 	[expr 0.1];
set ebres 	[expr 0.025];

uniaxialMaterial ConcretewBeta $ConcDiagMat $fpc $ec0 $fcint $ecint $fcres $ecres $ft $ftint $etint $ftres $etres -E $Ec -alpha $alpha -beta $bint $ebint $bres $ebres


# --- DEFINE NODAL PROPERTIES
node 1  	0.0 	0.0
node 2  	10.0 	0.0
node 3  	0.0 	10.0
node 4  	10.0 	10.0

# set the boundary conditions
fix 1  	1 	1
fix 2  	1 	1
fix 3  	0 	1
fix 4  	0 	1

equalDOF 3 4 1

# --- DEFINE ELEMENTS
set AconcDiag 7.07107;

# Diagonal concrete
element Truss2 	1 	1	4	2	3  $AconcDiag	$ConcDiagMat
element Truss2 	2 	2	3	1	4 	$AconcDiag	$ConcDiagMat

# --- DEFINE CYCLIC LOADING
set controlNode 3;
set load 1.0;
pattern Plain 1 Linear -factor 1 {
   load $controlNode $load 0.0;
}

# --- DEFINE RECORDERS
recorder Node -file "ConcwBetaExample_simpleDiags-FreeDisp.out" -load -nodes $controlNode -dof 1 disp

recorder Element -file "ConcwBetaExample_simpleDiags-diagonalStressStrain.out" -load -ele 1 2 -material stressStrain
recorder Element -file "ConcwBetaExample_simpleDiags-diagonalBeta.out" -load -ele 1 2 -material beta

# --- LOADING LOOP
set file [open "cyclicLoadingHistory.dat" r];
set factor [expr 10.0/100.0];
set Tol 1.0e-5;			# convergence tolerance for test

constraints Transformation
numberer Plain
system UmfPack 

set d1 0.;
set Nstep 5;
set startT [clock seconds]

while {[gets $file temp] > 0} {
	foreach d2 $temp {
		set d2 [expr {$factor*$d2}];
		set DLoad [expr {($d2 - $d1)/$Nstep}];
		puts [expr {$d1 + $Nstep*$DLoad}];
		
		for {set i 0} {$i < $Nstep} {incr i 1} {
			test NormDispIncr $Tol 10 0
			algorithm Newton
			integrator DisplacementControl $controlNode 1 $DLoad
			analysis Static
		    set ok [analyze 1]
			if {$ok != 0} {
				puts "Trying Newton with Initial Tangent.."
				test NormDispIncr $Tol 2000 0
				algorithm Newton -initial
				integrator DisplacementControl $controlNode 1 $DLoad
				analysis Static
				set ok [analyze 1]
			}
			if {$ok != 0} {
				remove recorders;
				return -1
		    };
		};
		set d1 $d2;
	}
}
puts "finished analysis ------"
remove recorders;

set endT [clock seconds]
puts "Execution time: [expr $endT-$startT] seconds."